package com.adc.da.system.controller;

import com.adc.da.dto.reqDTO.EnvBase64PictureRecognitionReqDTO;
import com.adc.da.system.entity.CheckCertificateInfoDetail;
import com.adc.da.system.service.ICheckCertificateInfoDetailService;
import com.adc.da.system.service.ICheckDataCheckResultService;
import com.adc.da.util.FileUtil;
import com.adc.da.base.web.BaseController;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-09-26
 */
@RestController
@RequestMapping("/${restPath}/check-certificate-info-detail")
public class CheckCertificateInfoDetailController extends BaseController {

    @Autowired
    ICheckCertificateInfoDetailService detailService;

    @Autowired
    private ICheckDataCheckResultService iCheckDataCheckResultService;

//    @Autowired
//    private ICheckOperationLogService iCheckOperationLogService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 图片识别
     *
     * @return
     */
    @ApiOperation(value = "|CheckCertificateInfoDetail|图片识别")
    @RequestMapping(value = "/envBase64PictureRecognition", method = RequestMethod.POST)
    public ResponseMessage envBase64PictureRecognition(
            @RequestBody EnvBase64PictureRecognitionReqDTO envBase64PictureRecognitionReqDTO) {
        CheckCertificateInfoDetail detail = new CheckCertificateInfoDetail();
        String[] imgBase64s = envBase64PictureRecognitionReqDTO.getImgBase64s();
        if (StringUtils.isEmpty(envBase64PictureRecognitionReqDTO.getCertificateType())) {
            return Result.error("0", "识别类型为空");
        }
        if (StringUtils.isEmpty(envBase64PictureRecognitionReqDTO.getInfoId())) {
            return Result.error("0", "证书id为空");
        }
        if (imgBase64s != null && imgBase64s.length > 0) {
            MultipartFile[] imgs = new MultipartFile[imgBase64s.length];
            for (int i = 0; i < imgBase64s.length; i++) {
                imgs[i] = FileUtil.base64ToMultipart(imgBase64s[i]);
            }
            detail = detailService.pictureRecognition(imgs,
                    envBase64PictureRecognitionReqDTO.getCertificateType(),
                    envBase64PictureRecognitionReqDTO.getInfoId(),
                    envBase64PictureRecognitionReqDTO.getUserId());
        }
        if (detail != null && StringUtils.isNotEmpty(detail.getContent())) {
            return Result.success("200", "识别成功", detail);
        } else if (detail != null && "-1".equals(detail.getId())) {
            return Result.error("0", "正面识别失败");
        } else if (detail != null && "-2".equals(detail.getId())) {
            return Result.error("0", "反面识别失败");
        } else {
            return Result.error("0", "识别失败");
        }
    }

    /**
     * 查询已识别数据
     *
     * @param certificateType
     * @param infoId
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "|CheckCertificateInfoDetail|图片识别数据查询")
    @GetMapping("/selectDetail")
    public ResponseMessage selectDetail(String certificateType, String infoId) throws Exception {
        if (StringUtils.isBlank(certificateType)) {
            Result.success("200", "查询成功", new CheckCertificateInfoDetail());
        }
        CheckCertificateInfoDetail detail = detailService.selectOne(certificateType, infoId);
        if (detail != null) {
            detail.setCheckResult(iCheckDataCheckResultService.selectByIdAndType(infoId, certificateType));
        }
        return Result.success("200", "查询成功", detail);
    }

    /**
     * 功能描述: 修改参数
     *
     * @param: id
     * @param: remark 备注
     * @return: ResponseMessage
     * @auther: 韩飞
     * @date: 2019/11/14
     */
//    @ApiOperation(value = "|CheckCertificateInfoDetail|修改参数")
//    @PostMapping("/updateValue")
//    @Transactional
//    public ResponseMessage updateRemark(String id, String content) {
//        if (StringUtils.isEmpty(id)) {
//            return Result.error("参数缺失");
//        }
//        if (StringUtils.isEmpty(content)) {
//            return Result.error("参数缺失");
//        }
//        UpdateWrapper wrapper = new UpdateWrapper();
//        wrapper.set("CONTENT", content);
//        wrapper.eq("ID", id);
//        boolean flag = detailService.update(wrapper);
//        if (flag) {
//            iCheckOperationLogService.operationLog(request.getHeader("userId"), "更新随车文件识别数据");
//            return Result.success("200", "操作成功", "true");
//        } else {
//            return Result.error("操作失败");
//        }
//    }

    /**
     * 功能描述: 查询核查完成的数据都上传了哪些证书证书
     *
     * @param: id
     * @auther: 凡昌松
     */
    @ApiOperation(value = "查询某个核查完成的数据都上传了哪些证书")
    @GetMapping("/selectCheckOkDetail")
    @Transactional
    public ResponseMessage selectCheckOkDetail(String id) {
        if (StringUtils.isEmpty(id)) {
            return Result.error("参数缺失");
        }
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("INFO_ID", id);
        wrapper.select("CERTIFICATE_TYPE");
        List<String> types = detailService.listObjs(wrapper);
        return Result.success("200", "操作成功", types);
    }
}
