package com.adc.da.system.controller;

import com.adc.da.dto.reqDTO.CertificateReqDTO;
import com.adc.da.dto.reqDTO.DataCheckReqDTO;
import com.adc.da.dto.resDTO.CertificateResDTO;
import com.adc.da.system.entity.CheckCertificateMainInfo;
import com.adc.da.system.service.ICheckCertificateMainInfoService;
import com.adc.da.base.web.BaseController;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.transaction.Transactional;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author 韩飞
 * @since 2019-09-26
 */
@RestController
@RequestMapping("/${restPath}/check-certificate-main-info")
public class CheckCertificateMainInfoController extends BaseController {

    @Autowired
    ICheckCertificateMainInfoService certificateService;


//    @Autowired
//    private ICheckOperationLogService iCheckOperationLogService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 功能描述: 分页查询
     *
     * @param: [page]
     * @return: IPage<COCResDTO>
     * @auther: 韩飞
     * @date: 2019/9/27
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|分页查询")
    @GetMapping("/getCertificatePage")
    public ResponseMessage page(CertificateReqDTO certificatePage) {
        if (StringUtils.isNotEmpty(certificatePage.getVehicleModel())){
            certificatePage.setVehicleModel(certificatePage.getVehicleModel().toUpperCase());
        }
        IPage<CertificateResDTO> rows = certificateService.queryByPage(certificatePage);
        return Result.success("200", "查询成功", rows);
    }

    /**
     * 功能描述: 复制新增
     *
     * @param: [page]
     * @return: IPage<COCResDTO>
     * @auther: 韩飞
     * @date: 2019/9/27
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|复制新增")
    @GetMapping("/addCertificate")
    public ResponseMessage addCertificate(CheckCertificateMainInfo certificate) {
        int rows = certificateService.add(certificate);
        if (rows == 1) {
            return Result.success("200", "复制成功",true);
        } else {
            return Result.error("0", "复制失败");
        }
    }

    /**
     * 功能描述: 删除复制
     *
     * @param: [page]
     * @return: IPage<COCResDTO>
     * @auther: 韩飞
     * @date: 2019/9/27
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|删除复制")
    @GetMapping("/delCertificate")
    public ResponseMessage delCertificate(String id) {
        int rows = certificateService.delCertificate(id);
        if (rows == 1) {
            return Result.success("200", "删除成功");
        } else {
            return Result.error("0", "删除失败");
        }
    }

    /**
     * 获取证书核查完成的车型
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|获取证书核查完成的车型")
    @GetMapping("/searchCheckOk")
    public ResponseMessage searchCheckOk() {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("CHECK_STATE", "2");
        return Result.success(certificateService.list(wrapper));
    }

    /**
     * 数据一致性比对
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|数据一致性比对")
    @PostMapping("/certificateDataCheck")
    public ResponseMessage certificateDataCheck(DataCheckReqDTO dataCheckReqDTO) {
        if (dataCheckReqDTO == null) {
            return Result.error("参数不能为空");
        }
        if (StringUtils.isEmpty(dataCheckReqDTO.getTypeObj()) || "{}".equals(dataCheckReqDTO.getTypeObj())) {
            return Result.error("识别结果不能为空");
        }
        if (StringUtils.isEmpty(dataCheckReqDTO.getType())) {
            return Result.error("识别类型不能为空");
        }
        if (StringUtils.isEmpty(dataCheckReqDTO.getCarTypeCode())) {
            return Result.error("车型编号不能为空");
        }
        if (StringUtils.isEmpty(dataCheckReqDTO.getId())) {
            return Result.error("ID不能为空");
        }
        if (StringUtils.isEmpty(dataCheckReqDTO.getGroup())) {
            return Result.error("批次不能为空");
        }
        if (StringUtils.isNotEmpty(dataCheckReqDTO.getObj()) && StringUtils.isNotEmpty(dataCheckReqDTO.getDetailId())) {
            certificateService.updateInfoDetail(dataCheckReqDTO.getDetailId(), dataCheckReqDTO.getObj());
        }
//        List<String> list = new ArrayList<>();
//        if (StringUtils.isNotEmpty(informationOpenNumber)) {
//            list = Arrays.asList(informationOpenNumber.split(","));
//        }
        return certificateService.dataCheck(dataCheckReqDTO);
    }

    /**
     * 功能描述: 证书核查完成
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|证书核查完成")
    @GetMapping("/checkOk")
    public ResponseMessage checkOk(String id, String userId) {
        if (StringUtils.isEmpty(id)) {
            return Result.error("参数缺失");
        }
        if (StringUtils.isEmpty(userId)) {
            return Result.error("参数缺失");
        }
        return certificateService.checkOk(id,userId);

    }
//    @ApiOperation(value = "|CheckCertificateMainInfo|验证是否5种")
//    @GetMapping("/checkIsOk")
//    public ResponseMessage checkIsOk(String id) {
//        if (StringUtils.isEmpty(id)) {
//            return Result.error("参数缺失");
//        }
//        //验证该车是否已经对比过5种证书
//       return certificateService.checkIsOk(id);
//    }


    /**
     * 功能描述: 修改备注
     *
     * @param: id
     * @param: remark 备注
     * @return: ResponseMessage
     * @auther: 韩飞
     * @date: 2019/9/27
     */
    @ApiOperation(value = "|CheckCertificateMainInfo|修改备注")
    @GetMapping("/updateRemark")
    @Transactional
    public ResponseMessage updateRemark(String id, String remark) {
        if (StringUtils.isEmpty(id)) {
            return Result.error("参数缺失");
        }
        if (StringUtils.isEmpty(remark)) {
            return Result.error("参数缺失");
        }
        UpdateWrapper wrapper = new UpdateWrapper();
        wrapper.set("REMARK", remark);
        wrapper.eq("ID", id);
        boolean flag = certificateService.update(wrapper);
        if (flag) {
//            iCheckOperationLogService.operationLog(request.getHeader("userId"),"修改随车文件备注");
            return Result.success("200", "操作成功","true");
        } else {
            return Result.error("操作失败");
        }
    }
}
