package com.adc.da.system.controller;


import com.adc.da.base.web.BaseController;
import com.adc.da.dto.resDTO.DownCheckFalseDTO;
import com.adc.da.excel.poi.excel.ExcelExportUtil;
import com.adc.da.excel.poi.excel.entity.ExportParams;
import com.adc.da.excel.poi.excel.entity.enums.ExcelType;
import com.adc.da.system.service.ICheckDataCheckResultService;
import com.adc.da.util.ReadExcel;
import com.adc.da.util.exception.AdcDaBaseException;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.adc.da.util.utils.DateUtils;
import com.adc.da.util.utils.IOUtils;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import java.util.List;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-10-17
 */
@RestController
@RequestMapping("/${restPath}/check-data-check-result")
public class CheckDataCheckResultController extends BaseController {


    @Autowired
    private ICheckDataCheckResultService iCheckDataCheckResultService;


    /**
     * 根据证书核查ID和证书类型获取核查结果
     * @param id
     * @param type
     * @return
     */
    @ApiOperation(value = "|CheckDataCheckResult|根据证书核查ID和证书类型获取核查结果")
    @GetMapping("/selectByIdAndType")
    public ResponseMessage selectByIdAndType(String id, String type) {
        return Result.success(iCheckDataCheckResultService.selectByIdAndType(id, type));
    }
    /**
     * 对比详情导出
     * @param id
     * @param type
     * @return
     */
    @ApiOperation(value = "|CheckDataCheckResult|导出对比详情")
    @GetMapping("/exportCheckResult")
    public void exportCheckResult(HttpServletResponse response, HttpServletRequest request, String id, String type) {
        if (StringUtils.isBlank(id) || StringUtils.isBlank(type)) {
            throw new AdcDaBaseException("导出随车文件对比详情时参数缺失");
        }
        iCheckDataCheckResultService.exportCheckResult(response,request,id,type);
    }
    /**
     * 分页查询随车文件一致性对比不一致数据
     * @return
     */
    @ApiOperation(value = "|CheckDataCheckResult|分页查询随车文件一致性对比不一致数据")
    @GetMapping("/getCheckFalsePage")
    public ResponseMessage getCheckFalsePage(int page,int limit,String address,String project,String isHandel,
                                             String carGroup,String editionCode,String paramName) {
        return Result.success("200","查询成功", iCheckDataCheckResultService.getListInfo(page,limit,address,project,isHandel
                ,carGroup,editionCode,paramName));
    }

    /**
     * 处理随车文件一致性对比不一致数据
     * @return
     */
    @ApiOperation(value = "|CheckDataCheckResult|处理随车文件一致性对比不一致数据")
    @GetMapping("/updateCheckFalse")
    public ResponseMessage updateCheckFalse(String id) {
        if (StringUtils.isBlank(id)) {
            return Result.error("操作失败");
        }
        if (iCheckDataCheckResultService.updateCheckFalse(id)) {
            return Result.success("200","操作成功","");
        }
        return Result.error("操作失败");
    }
    /**
     * 导出随车文件一致性对比不一致数据
     * @return
     */
    @ApiOperation(value = "|CheckDataCheckResult|导出随车文件一致性对比不一致数据")
    @GetMapping("/downCheckFalse")
    public void downCheckFalse(String address,String project,String isHandel, HttpServletResponse response, HttpServletRequest request,
                               String carGroup,String editionCode,String paramName) {

        OutputStream os = null;
        Workbook workbook = null;
        try {
            response.setHeader("Content-Disposition",
                    "attachment; filename=" + ReadExcel.encodeFileName( "随车文件待处理问题.xlsx", request));
            response.setContentType("application/force-download");
            ExportParams exportParams = new ExportParams();
            exportParams.setType(ExcelType.XSSF);

            List<DownCheckFalseDTO> datas =  iCheckDataCheckResultService.downCheckFalse(address,project,isHandel,
                    carGroup,editionCode,paramName);
            for (DownCheckFalseDTO downCheckFalseDTO : datas) {
                downCheckFalseDTO.setCheckTimeStr(DateUtils.dateToString(downCheckFalseDTO.getCheckTime(),"yyyy-MM-dd HH:mm:ss"));
                downCheckFalseDTO.setCheckResult(downCheckFalseDTO.getCheckResult().equals("2")?"处理完成":"不一致");
            }
            workbook = ExcelExportUtil.exportExcel(exportParams, DownCheckFalseDTO.class, datas);
            os = response.getOutputStream();
            workbook.write(os);
            os.flush();
        } catch (Exception e) {
            throw new AdcDaBaseException("下载文件失败，请重试");
        } finally {
            IOUtils.closeQuietly(os);
        }
    }
}
