package com.adc.da.system.controller;

import com.adc.da.dto.reqDTO.CheckMenuManagementReqDTO;
import com.adc.da.system.entity.CheckCheckMenuManagement;
import com.adc.da.base.web.BaseController;
import com.adc.da.system.service.ICheckBulletinDataParameterService;
import com.adc.da.system.service.ICheckCheckMenuManagementService;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 核查清单设置
 * </p>
 *
 * @author 凡昌松
 * @since 2019-09-26
 */
@RestController
@RequestMapping("/${restPath}/CheckMenuManagement")
public class CheckMenuManagementController extends BaseController {
    @Autowired
    private ICheckBulletinDataParameterService iCheckBulletinDataParameterService;
    @Autowired
    private ICheckCheckMenuManagementService iCheckCheckMenuManagementService;

    /**
     * 获取所有公告参数
     * @param parameterCode
     * @param parameterName
     * @return
     */
    @ApiOperation(value = "获取所有公告参数")
    @GetMapping(value = "/getNoticeParameter")
    public ResponseMessage getNoticeParameter(String obdId, String parameterCode,String parameterName) {
        if (StringUtils.isNotEmpty(parameterCode)){
            parameterCode = parameterCode.toUpperCase();
        }
        return iCheckBulletinDataParameterService.getNoticeParameter(obdId,parameterCode,parameterName);
    }

    /**
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "添加核查参数")
    @GetMapping(value = "/addParameter")
    public ResponseMessage addParameter(String id){
        return iCheckCheckMenuManagementService.addNoticeParameter(id);
    }

    /**
     *
     * @param type
     * @param parameterCode
     * @param parameterName
     * @return
     */
    @ApiOperation(value = "获取所有CCC参数或者环保参数")
    @GetMapping("getCCCParameterOrENV")
    public ResponseMessage getCCCParameterOrENV(String mouldId,String type,String parameterCode,String parameterName){
        if (StringUtils.isNotEmpty(parameterCode)){
            parameterCode = parameterCode.toUpperCase();
        }
        return iCheckCheckMenuManagementService.getCCCParameterOrENV(mouldId,type,parameterCode,parameterName);
    }

    /**
     *
     * @return
     */
    @ApiOperation(value = "添加CCC参数或者环保参数")
    @PostMapping("addCCCParameterOrENV")
    public ResponseMessage getCCCParameterOrENV(@RequestBody CheckMenuManagementReqDTO checkMenuManagementReqDTO){
        if (checkMenuManagementReqDTO == null || StringUtils.isBlank(checkMenuManagementReqDTO.getMouldId())) {
            return Result.error("-1","参数缺失");
        }

        List<String> ids;
        List<String> ggParameter = (List<String>) iCheckCheckMenuManagementService.addNoticeParameter(String.join(",",checkMenuManagementReqDTO.getAddNoticeData())).getData();
        switch (checkMenuManagementReqDTO.getType()){
            case "3":
                ids = checkMenuManagementReqDTO.getCccIds();
                ids.addAll(checkMenuManagementReqDTO.getEnvIds());
                ids.addAll(ggParameter != null ? ggParameter:new ArrayList<>());
                break;
            case "4":
                ids = checkMenuManagementReqDTO.getCccIdsHc();
                break;
            case "5":
                ids = checkMenuManagementReqDTO.getCccIdsNew();
                break;
            default:
                ids = checkMenuManagementReqDTO.getEnvIds();
                ids.addAll(checkMenuManagementReqDTO.getCccIds());
                ids.addAll(ggParameter != null ? ggParameter:new ArrayList<>());
        }
        return iCheckCheckMenuManagementService.addCCCParameterOrENV(ids,checkMenuManagementReqDTO.getType(),checkMenuManagementReqDTO.getMouldId());
    }

    /**
     *
     * @return
     */
    @ApiOperation(value = "获取所有选定的核查参数")
    @GetMapping("getAllTrueParameter")
    public ResponseMessage getAllTrueParameter(){
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("PARAMETER_STATE","0");
        return Result.success(iCheckCheckMenuManagementService.list(wrapper));
    }
    //保存核查项关联关系
    @ApiOperation(value = "保存核查项关联关系")
    @PostMapping("saveRelationship")
    public ResponseMessage saveRelationship(String obdId,String detailIds){
        if(StringUtils.isNotBlank(obdId) && StringUtils.isNotBlank(detailIds)){
            return Result.success("200","添加成功",iCheckCheckMenuManagementService.insertRelationship(obdId,detailIds));
        }else{
            return Result.error("添加失败");
        }
    }
    //删除核查项关联关系
    @ApiOperation(value = "删除核查项关联关系")
    @PostMapping("deleteRelationshipByMenuId")
    public ResponseMessage deleteRelationshipByMenuId(@RequestParam String id){
        if (StringUtils.isNotBlank(id)){
            return Result.success("200","删除成功",iCheckCheckMenuManagementService.deleteRelationshipByMenuId(id));
        }else{
            return Result.error("删除失败");
        }
    }
    //通过obdid查menu信息
    @ApiOperation(value = "通过obdId获取Menu参数信息")
    @PostMapping("queryMenuInfoByObdid")
    public List<CheckCheckMenuManagement> queryMenuInfoByObdid(@RequestParam String obdId){
        if (StringUtils.isNotBlank(obdId)){
            return iCheckCheckMenuManagementService.queryMenuInfoByObdid(obdId);
        }else{
            return null;
        }
    }
    //通过obdid查CHECK_OBD_DETIAL信息
    @ApiOperation(value = "通过obdId获取CHECK_OBD_DETIAL参数信息")
    @PostMapping("queryObdDetailInfoByObdid")
    public ResponseMessage queryObdDetailInfoByObdid(@RequestParam String obdId){
        if (StringUtils.isNotBlank(obdId)){
            return iCheckCheckMenuManagementService.queryObdDetailInfoByObdid(obdId);
        }else{
            return Result.error("查询失败");
        }
    }

}
