package com.adc.da.system.controller;


import com.adc.da.system.entity.CheckObd;
import com.adc.da.system.entity.TsOrg;
import com.adc.da.system.service.ICheckObdService;
import com.adc.da.system.service.impl.CheckObdOrgServiceImpl;
import com.adc.da.base.web.BaseController;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.adc.da.util.utils.UserUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
 * OBD参数审核表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2021-03-30
 */
@RestController
@RequestMapping("/${restPath}/check-obd")
public class CheckObdController extends BaseController {

    @Autowired
    private ICheckObdService checkObdService;
    @Autowired
    private CheckObdOrgServiceImpl checkObdOrgService;

    /**
     * 模糊查询（带有分页和排序）
     * @param page 页
     * @param limit 长度
     * @param obdName 模板名称
     * @param operator 创建人
     * @param base 事业部
     * @param sort 排序字段
     * @param isAsc 是否正序
     * @return 查询结果
     */
    @ApiOperation(value ="查询OBD列表")
    @GetMapping("/getListInfo")
    public ResponseMessage getListInfo(Integer page, Integer limit,String obdName,String operator,String base,
                                       String sort, String isAsc,String type,String userBase,String startTime,String endTime){
        base = UserUtil.getQyId();
        return Result.success("200","查询成功",checkObdService.queryCheckObd(page,limit,obdName,operator,
                base,sort,isAsc,type,userBase,startTime,endTime));
    }

    /**
     * 查询关联的检索项目id
     * @return 返回结果项目id
     */
    @ApiOperation(value = "查询关联的检索项目id")
    @GetMapping("/selectDetailObd")
    public ResponseMessage selectDetailObd(@RequestParam String id){
        return  Result.success("200","查询成功",checkObdService.selectDetailObd(id));
    }

    /**
     * 查询事业部
     * @return 返回结果
     */
    @ApiOperation(value = "查询全部的事业部")
    @GetMapping("/selectOrg")
    public ResponseMessage selectOrg(){
        return  Result.success("200","查询成功",checkObdService.selectOrg());
    }

    /**
     * 添加
     * @return 添加结果
     */
    @ApiOperation(value = "添加OBD")
    @PostMapping("/insertObd")
    public ResponseMessage insertObd(@RequestBody CheckObd checkObd){
        checkObd.setBase(UserUtil.getQyId());
        checkObd.setDistributionBase(UserUtil.getQyId());
        return Result.success("200","添加成功",checkObdService.insertObd(checkObd));
    }

    /**
     * 修改
     * @param checkObd obd实体类
     * @return 修改结果
     */
    @ApiOperation(value = "修改OBD")
    @PutMapping("/updateObd")
    public ResponseMessage updateObd(@RequestBody CheckObd checkObd){
        if (StringUtils.isBlank(checkObd.getBase()) || StringUtils.isBlank(checkObd.getUserBase())) {
            return Result.error("参数缺失");
        }
//        List<String> idList = Arrays.asList(id.split(","));
        List<String> baseIds = new ArrayList<>();
        List<String> userBases = Arrays.asList(checkObd.getUserBase().split(","));
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.in("OBD_ID",checkObd.getId());
        wrapper.select("DISTINCT ORG_ID");
        baseIds = checkObdOrgService.listObjs(wrapper);
        baseIds.removeAll(userBases);
        if (baseIds.size()>0) {
            List<String> baseName = new ArrayList<>();
            QueryWrapper<TsOrg> orgQueryWrapper = new QueryWrapper<>();
            orgQueryWrapper.in("ID",baseIds);
            orgQueryWrapper.select("ORG_NAME");
            baseName = checkObdOrgService.getBaseNameByOrgIds(baseIds);
            if (baseName.size()>0) {
                return Result.error("您不具有" + String.join("、",baseName) +"事业部权限,无法编辑数据");
            }
        }
        return Result.success("200","修改成功",checkObdService.updateObd(checkObd));
    }

    /**
     * 删除
     * @param id 模板id
     * @return
     */
    @ApiOperation(value = "删除OBD")
    @DeleteMapping("/deleteObd")
    public ResponseMessage deleteObd(String id,String userBase){
        if (StringUtils.isBlank(id) || StringUtils.isBlank(userBase)) {
            return Result.error("参数缺失");
        }
        List<String> idList = Arrays.asList(id.split(","));
        List<String> baseIds = new ArrayList<>();
        List<String> userBases = Arrays.asList(userBase.split(","));
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.in("OBD_ID",idList);
        wrapper.select("DISTINCT ORG_ID");
        baseIds = checkObdOrgService.listObjs(wrapper);
        baseIds.removeAll(userBases);
        if (baseIds.size()>0) {
            List<String> baseName = new ArrayList<>();
            QueryWrapper<TsOrg> orgQueryWrapper = new QueryWrapper<>();
            orgQueryWrapper.in("ID",baseIds);
            orgQueryWrapper.select("ORG_NAME");
            baseName = checkObdOrgService.getBaseNameByOrgIds(baseIds);
            if (baseName.size()>0) {
                return Result.error("您不具有" + String.join("、",baseName) +"事业部权限,无法删除数据");
            }
        }
        return Result.success("200","删除成功",checkObdService.deleteObd(id));
    }

    /**
     * 查询
     * @param baseId
     * @param mouldType
     * @return
     */
    @ApiOperation(value = "根据事业部id查询模板")
    @GetMapping("/selectMouldByBase")
    public ResponseMessage selectMouldByBase(String baseId, String mouldType,String standType){
        baseId = UserUtil.getQyId();
        return Result.success("200","查询成功",checkObdService.selectMouldByBase(baseId,mouldType,standType));
    }

    /**
     * 查询模板信息
     * @param baseId
     * @param mouldType
     * @param mouldName
     * @return
     */
    @ApiOperation(value = "根据事业部id，模板类型，模板名称查询模板信息")
    @GetMapping("/selectCountByBaseAndName")
    public ResponseMessage selectCountByBaseAndName(String baseId, String mouldType,String mouldName,String id){
        if(StringUtils.isBlank(baseId) || StringUtils.isBlank(mouldName) || StringUtils.isBlank(mouldType)){
            return Result.error("-1","参数缺失");
        }
        int num = checkObdService.selectCountByBaseAndName(baseId,mouldType,mouldName,id);
        return Result.success("200","查询成功",num);
    }
    @ApiOperation(value = "修改OBD")
    @GetMapping("/canUpdateObd")
    public ResponseMessage canUpdateObd(String base,String userBase,String id){
        if (StringUtils.isBlank(id) || StringUtils.isBlank(userBase)) {
            return Result.error("参数缺失");
        }
//        List<String> idList = Arrays.asList(id.split(","));
        List<String> baseIds = new ArrayList<>();
        List<String> userBases = Arrays.asList(userBase.split(","));
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.in("OBD_ID",id);
        wrapper.select("DISTINCT ORG_ID");
        baseIds = checkObdOrgService.listObjs(wrapper);
        baseIds.removeAll(userBases);
        if (baseIds.size()>0) {
            List<String> baseName = new ArrayList<>();
            QueryWrapper<TsOrg> orgQueryWrapper = new QueryWrapper<>();
            orgQueryWrapper.in("ID",baseIds);
            orgQueryWrapper.select("ORG_NAME");
            baseName = checkObdOrgService.getBaseNameByOrgIds(baseIds);
            if (baseName.size()>0) {
                return Result.error("您不具有" + String.join("、",baseName) +"事业部权限,无法编辑数据");
            }
        }
        return Result.success();
    }
}
