package com.adc.da.system.controller;


import com.adc.da.dto.reqDTO.CheckCodeDetailDTO;
import com.adc.da.dto.reqDTO.CheckObdDetailDTO;
import com.adc.da.system.entity.CheckObdDetail;
import com.adc.da.system.entity.TsOrg;
import com.adc.da.system.service.ICheckObdDetailService;
import com.adc.da.system.service.impl.CheckObdOrgServiceImpl;
import com.adc.da.util.ReadExcel;
import com.adc.da.base.web.BaseController;

import com.adc.da.excel.poi.excel.ExcelExportUtil;
import com.adc.da.excel.poi.excel.entity.ExportParams;
import com.adc.da.excel.poi.excel.entity.enums.ExcelType;
import com.adc.da.util.exception.AdcDaBaseException;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.adc.da.util.utils.IOUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2021-04-01
 */
@RestController
@RequestMapping("/${restPath}/check-obd-detail")
public class CheckObdDetailController extends BaseController {

    @Autowired
    private ICheckObdDetailService checkObdDetailService;
    @Autowired
    private CheckObdOrgServiceImpl checkObdOrgService;
//    @Autowired
//    private ICheckBulletinDataParameterService iCheckBulletinDataParameterService;
//
//    @Autowired
//    private DetailInfoServiceImpl detailInfoService;
//
//    @Autowired
//    private ICheckCheckMenuManagementService iCheckCheckMenuManagementService;


    /**
     *
     * @param page 页
     * @param limit 长度
     * @param obdDetailName 检索项目名称
     * @param userId 创建人
     * @param baseId 事业部
     * @param sort 排序字段
     * @param isAsc 是否正序
     * @param type 模板类型
     * @return
     */
    @ApiOperation(value ="查询OBD核查项维护列表")
    @GetMapping("/getListInfo")
    public ResponseMessage getListInfo(Integer page, Integer limit, String obdDetailName, String userId, String baseId,
                                       String sort, String isAsc ,String type){
        return Result.success("200","查询成功",checkObdDetailService.queryDetail(page,limit,obdDetailName,
                userId,baseId,sort,isAsc,type));
    }

    /**
     * 增加OBD核查项维护列表
     * @param checkObdDetail 核查项实体类
     * @return
     */
    @ApiOperation(value ="增加OBD核查项维护列表")
    @PostMapping("/insertDetail")
    public ResponseMessage insertDetail(@RequestBody CheckObdDetail checkObdDetail){
        return Result.success("200","添加成功",checkObdDetailService.insertDetail(checkObdDetail));
    }

    /**
     * 修改OBD核查项维护列表
     * @param checkObdDetail 核查项实体类
     * @return
     */
    @ApiOperation(value ="修改OBD核查项维护列表")
    @PutMapping("/updateDetail")
    public ResponseMessage updateDetail(@RequestBody CheckObdDetail checkObdDetail){
        return Result.success("200","修改成功",checkObdDetailService.updateDetail(checkObdDetail));
    }

    /**
     * 删除OBD核查项维护列表
     * @param id 检索项目id
     * @return
     */
    @ApiOperation(value ="删除OBD核查项维护列表")
    @DeleteMapping("/deleteDetail")
    public ResponseMessage deleteDetail(String id,String userBase){
        if (StringUtils.isBlank(id) || StringUtils.isBlank(userBase)) {
            return Result.error("参数缺失");
        }
        List<String> idList = Arrays.asList(id.split(","));
        List<String> baseIds = new ArrayList<>();
        List<String> userBases = Arrays.asList(userBase.split(","));
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.in("OBD_ID",idList);
        wrapper.select("DISTINCT ORG_ID");
        baseIds = checkObdOrgService.listObjs(wrapper);
        baseIds.removeAll(userBases);
        if (baseIds.size()>0) {
            List<String> baseName = new ArrayList<>();
            QueryWrapper<TsOrg> orgQueryWrapper = new QueryWrapper<>();
            orgQueryWrapper.in("ID",baseIds);
            orgQueryWrapper.select("ORG_NAME");
            baseName = checkObdOrgService.getBaseNameByOrgIds(baseIds);
            if (baseName.size()>0) {
                return Result.error("您不具有" + String.join("、",baseName) +"事业部权限,无法删除数据");
            }
        }
        return Result.success("200","删除成功",checkObdDetailService.deleteDetail(id));
    }

    /**
     * 导入OBD核查维护项
     * @param file 文件
     * @param userId
     * @param baseId
     * @param type
     * @return
     */
    @ApiOperation(value = "导入OBD核查维护项")
    @PostMapping("/importObdDetail")
    public ResponseMessage importObdDetail(MultipartFile file, String userId, String baseId, String type){
        String fileName=file.getOriginalFilename();
        String prefix=fileName.substring(fileName.lastIndexOf(".")+1);
        ReadExcel readExcel = new ReadExcel();
        if (!readExcel.validateExcel(file.getOriginalFilename())) {
            return Result.error("fail", "请上传excel文件");
        }
        if(prefix.equals("xls") ||prefix.equals("xlsx")){
            Map<String,Object> map =checkObdDetailService.importObdDetail(file,userId, baseId,type);
            if ( map != null && map.get("FieldLength") != null && map.get("FieldLength").equals(1)){
                return Result.error("-1", "所有字段长度不能超过1000字符");
            }else if(map !=null && map.get("ObdDetailName") !=null&&map.get("ObdDetailName").equals(1)){
                return Result.error("-1","检查项目不能为空");
            }else if("2".equals(type) && map !=null && map.get("projectName") !=null && map.get("projectName").equals(1)){
                return Result.error("-1","总成名称不能为空");
            }else if(map != null){
                return Result.success("200","操作成功",map);
            }
            return Result.error("-1","请按照模板上传文件");
        }
        return Result.success("-1", "请上传xls或者xlsx文件");
    }

    /**
     * 模板下载
     * @param response
     * @param request
     * @return
     */
    @ApiOperation(value ="模板下载")
    @GetMapping("/downTemplate")
    public ResponseMessage exportObdDetail(HttpServletResponse response, HttpServletRequest request,String type){

        OutputStream os = null;
        Workbook workbook = null;
        try {
            if("1".equals(type)){
                response.setHeader("Content-Disposition",
                        "attachment; filename=" + ReadExcel.encodeFileName( "OBD核查项维护.xlsx", request));
            }else if("2".equals(type)){
                response.setHeader("Content-Disposition",
                        "attachment; filename=" + ReadExcel.encodeFileName( "扫码符合性模板.xlsx", request));
            }
            response.setContentType("application/force-download");
            ExportParams exportParams = new ExportParams();
            exportParams.setType(ExcelType.XSSF);
            List<String> dates = new ArrayList<>();
            if("1".equals(type)){
                workbook = ExcelExportUtil.exportExcel(exportParams, CheckObdDetailDTO.class,dates);
            }else if("2".equals(type)){
                workbook = ExcelExportUtil.exportExcel(exportParams, CheckCodeDetailDTO.class,dates);
            }
            os = response.getOutputStream();
            workbook.write(os);
            os.flush();
        } catch (Exception e) {
            throw new AdcDaBaseException("下载文件失败，请重试");
        } finally {
            IOUtils.closeQuietly(os);
        }
        return Result.success("0", "操作成功");
    }

    /**
     * 验重
     * @param baseId
     * @param detailType
     * @param detailName
     * @param id
     * @return
     */
    @ApiOperation(value = "根据事业部id，模板类型，模板名称查询模板信息")
    @GetMapping("/selectCountByItemAndBase")
    public ResponseMessage selectCountByItemAndBase(String baseId, String detailType,String detailName,String id){
        if(StringUtils.isBlank(baseId) || StringUtils.isBlank(detailType) || StringUtils.isBlank(detailName)){
            return Result.error("-1","参数缺失");
        }
        int num = checkObdDetailService.selectCountByItemAndBase(baseId,detailType,detailName,id);
        return Result.success("200","查询成功",num);
    }

    @ApiOperation(value = "根据类型查询核查项列表")
    @GetMapping("/getDetailListByType")
    public ResponseMessage getDetailListByType(String baseId,String detailType,String obdId,String remarks){
        if(StringUtils.isBlank(baseId) || StringUtils.isBlank(detailType)){
            return Result.error("-1","参数缺失");
        }
        return Result.success("200","查询成功",checkObdDetailService.getDetailListByType(baseId,detailType,obdId,remarks));
    }

//    @ApiOperation(value = "根据关键件类型查询参数编号")
//    @GetMapping("/getCodeByKeyType")
//    public ResponseMessage getCodeByKeyType(String keyType){
//        if(StringUtils.isBlank(keyType) || StringUtils.isBlank(keyType)){
//            return Result.error("-1","参数缺失");
//        }
//        List<CheckCheckMenuManagement> result = new ArrayList<>();
//        switch (keyType){
//            case "0":
//                result  = iCheckBulletinDataParameterService.getAllGgParameter();
//                break;
//            case "1":
//                result = iCheckCheckMenuManagementService.list(new QueryWrapper<CheckCheckMenuManagement>().eq(
//                        "PARAMETER_TYPE","2").select("PARAMETER_DATA as PARAMETER_CODE_ONE","PARAMETER_NAME"));
//                break;
//            case "2":
//                result = detailInfoService.getAllCCCParameter();
//                break;
//            default:
//                break;
//        }
//        return Result.success("200","查询成功",result);
//    }


}
