package com.adc.da.system.controller;


import com.adc.da.dto.reqDTO.CheckRealVehicleVerificationDto;
import com.adc.da.system.entity.CheckRealVehicleVerification;
import com.adc.da.system.service.ICheckRealVehicleVerificationService;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * 实车核查第三页面
 */
@RestController
@Api(value = "实车核查第三页面")
@RequestMapping("/${restPath}/checkRealVehicleVerification")
public class CheckRealVehicleVerificationController {
    /**
     * request
     */
    @Autowired
    private HttpServletRequest request;
    /**
     * 日志service
     */
//    @Autowired
//    private ICheckOperationLogService iCheckOperationLogService;
//    /**
//     * 实车
//     */
    @Autowired
    private ICheckRealVehicleVerificationService checkRealVehicleVerificationService;
//
//    @Autowired
//    private ICheckModelSeriesListService iCheckModelSeriesListService;

    @Value("${uploadFile}")
    private String uploadFile;

    /**
     * 保存实车核查列表
     *
     * @param checkRealVehicleVerificationDto
     * @return
     */
    @ApiOperation(value = "|saveInfo|保存实车核查列表")
    @PostMapping("/saveInfo")
    public ResponseMessage saveInfo(@RequestBody CheckRealVehicleVerificationDto checkRealVehicleVerificationDto) {
//        最终合成列表List
        QueryWrapper<CheckRealVehicleVerification> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("VEHICLE_SERIES_ID", checkRealVehicleVerificationDto.getVehicleSeriesId());
        queryWrapper.likeLeft("ID", "_" + checkRealVehicleVerificationDto.getParameterType());
        if (checkRealVehicleVerificationDto.getParameterType().equals("3")
                || checkRealVehicleVerificationDto.getParameterType().equals("4")
                || checkRealVehicleVerificationDto.getParameterType().equals("5")) {
            queryWrapper.eq("PARAMETER", checkRealVehicleVerificationDto.getParameterCodeOne());
        } else {
            queryWrapper.and(wrapper -> wrapper.eq("PARAMETER_NAME", checkRealVehicleVerificationDto.getParameterName())
                    .or()
                    .eq("PARAMETER_NAME", checkRealVehicleVerificationDto.getParameterName() + " 1"));
        }
        if (checkRealVehicleVerificationService.count(queryWrapper) > 0 || checkRealVehicleVerificationService.saveInfo(checkRealVehicleVerificationDto)) {
            return Result.success("200", "操作成功", null);
        }
        return Result.error("-1", "无匹配的数据");
    }

    /**
     * 检索核查列表
     */
    @ApiOperation(value = "|queryAll|检索核查列表")
    @GetMapping("/queryAll")
    public ResponseMessage queryAll(CheckRealVehicleVerification checkRealVehicleVerification, String status,
                                    String isCheck) {
        Page page = new Page(checkRealVehicleVerification.getPage(), checkRealVehicleVerification.getPageSize());
        QueryWrapper<CheckRealVehicleVerification> queryWrapper = new QueryWrapper<>();
        if("4".equals(checkRealVehicleVerification.getCheckType())){
            if(StringUtils.isNotBlank(checkRealVehicleVerification.getProject())) {
                queryWrapper.like("PROJECT", checkRealVehicleVerification.getProject());
            }
            if(StringUtils.isNotBlank(checkRealVehicleVerification.getType())){
                queryWrapper.eq("TYPE",checkRealVehicleVerification.getType());
            }
        }
        if("2".equals(checkRealVehicleVerification.getCheckType())){
            if(StringUtils.isNotBlank(checkRealVehicleVerification.getVehicleSeries())) {
                queryWrapper.like("PARAMETER_NAME", checkRealVehicleVerification.getVehicleSeries());
            }
            if(StringUtils.isNotBlank(checkRealVehicleVerification.getType())){
                queryWrapper.eq("TYPE",checkRealVehicleVerification.getType());
            }
            if(StringUtils.isNotBlank(checkRealVehicleVerification.getCheckPicturePathTwo())){
                queryWrapper.eq("CHECK_PICTURE_PATH_TWO",checkRealVehicleVerification.getCheckPicturePathTwo());
            }
        }
        queryWrapper.eq("VEHICLE_SERIES_ID", checkRealVehicleVerification.getVehicleSeriesId());
        if (StringUtils.isNotBlank(checkRealVehicleVerification.getCheckType())) {
            queryWrapper.eq("CHECK_TYPE",checkRealVehicleVerification.getCheckType());
        } else {
            queryWrapper.likeLeft("ID", "_" + checkRealVehicleVerification.getParameterType());
        }
        if(StringUtils.isNotBlank(checkRealVehicleVerification.getCheckResult())){
            queryWrapper.eq("CHECK_RESULT",checkRealVehicleVerification.getCheckResult());
        }
        if ("3".equals(checkRealVehicleVerification.getParameterType())
                || "4".equals(checkRealVehicleVerification.getParameterType())
                || "5".equals(checkRealVehicleVerification.getParameterType())) {
            queryWrapper.eq("PARAMETER", checkRealVehicleVerification.getParameter());
        } else if (StringUtils.isNotBlank(checkRealVehicleVerification.getParameterName())){
            queryWrapper.and(wrapper -> wrapper.eq("PARAMETER_NAME", checkRealVehicleVerification.getParameterName())
                    .or()
                    .like("PARAMETER_NAME", checkRealVehicleVerification.getParameterName()));
        }

        if (StringUtils.isNotEmpty(status)) {
            queryWrapper.ne("TYPE", "0");
            queryWrapper.isNotNull("TYPE");
        }
        if (checkRealVehicleVerification.getOrderBy() != null) {
            switch (checkRealVehicleVerification.getOrderBy()) {
                case "parameterName":
                    checkRealVehicleVerification.setOrderBy("NLSSORT(PARAMETER_NAME,'NLS_SORT = SCHINESE_PINYIN_M')");
                    break;
                case "vehicleType":
                    checkRealVehicleVerification.setOrderBy("VEHICLE_TYPE");
                    break;
                case "paramConfig":
                    checkRealVehicleVerification.setOrderBy("NLSSORT(PARAM_CONFIG,'NLS_SORT = SCHINESE_PINYIN_M')");
                    break;
                case "type":
                    checkRealVehicleVerification.setOrderBy("TYPE");
                    break;
                case "remarks":
                    checkRealVehicleVerification.setOrderBy("NLSSORT(REMARKS,'NLS_SORT = SCHINESE_PINYIN_M')");
                    break;
                case "checkPicturePathTwo":
                    checkRealVehicleVerification.setOrderBy("CHECK_PICTURE_PATH_TWO");
                    break;
                case "project":
                    checkRealVehicleVerification.setOrderBy("NLSSORT(PROJECT,'NLS_SORT = SCHINESE_PINYIN_M')");
                    break;
                case "checkPicturePath":
                    checkRealVehicleVerification.setOrderBy("CHECK_PICTURE_PATH");
                    break;
                case "checkResult":
                    checkRealVehicleVerification.setOrderBy("CHECK_RESULT");
                    break;
                case "dischargeStage":
                    checkRealVehicleVerification.setOrderBy("DISCHARGE_STAGE");
                    break;
                case "recordFaultCode":
                    checkRealVehicleVerification.setOrderBy("RECORD_FAULT_CODE");
                    break;
                default:
                    checkRealVehicleVerification.setOrderBy("ID");
                    break;
            }
            if (StringUtils.isBlank(checkRealVehicleVerification.getOrder()) || checkRealVehicleVerification.getOrder().equals("asc")) {
                queryWrapper.orderByAsc(checkRealVehicleVerification.getOrderBy());
            } else {
                queryWrapper.orderByDesc(checkRealVehicleVerification.getOrderBy());
            }
        }
        if (StringUtils.isNotEmpty(isCheck) && !"1".equals(checkRealVehicleVerification.getCheckType())
                && !"2".equals(checkRealVehicleVerification.getCheckType()) && !"4".equals(checkRealVehicleVerification.getCheckType())) {
            queryWrapper.orderByDesc("TYPE");
            queryWrapper.orderByDesc("CHECK_RESULT");
            queryWrapper.orderByAsc( "nlssort(PARAMETER_NAME,'NLS_SORT=SCHINESE_PINYIN_M')");
            queryWrapper.orderByDesc("ID");
        }
        if ("1".equals(checkRealVehicleVerification.getCheckType())) {
            queryWrapper.last(" ORDER BY CHECK_RESULT nulls last");
        }
        if ("2".equals(checkRealVehicleVerification.getCheckType()) || "4".equals(checkRealVehicleVerification.getCheckType())) {
            queryWrapper.last(" ORDER BY TYPE nulls last");
        }
//        if ("4".equals(checkRealVehicleVerification.getCheckType())) {
//            queryWrapper.last(" ORDER BY TYPE nulls last");
//        }
        return Result.success("200", "实车核查列表", checkRealVehicleVerificationService.page(page, queryWrapper));
    }

    /**
     * 保存核查结果
     *
     * @param checkRealVehicleVerificationDto
     * @return
     */
    @ApiOperation(value = "|saveById|保存核查结果")
    @PostMapping("/saveById")
    public ResponseMessage saveById(@RequestBody CheckRealVehicleVerificationDto checkRealVehicleVerificationDto) {
        if (checkRealVehicleVerificationDto.getList() == null) {
            return Result.error("-1", "请输入要保存的信息");
        }
        if (checkRealVehicleVerificationService.saveById(checkRealVehicleVerificationDto)) {
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "保存核查结果");
            return Result.success("200", "操作成功", null);
        }
        return Result.error("-1", "请输入要保存的信息");
    }
//
//
//    @ApiOperation(value = "|saveDetailForScanCode|保存扫码符合性核查列表")
//    @GetMapping("/saveDetailForScanCode")
//    public ResponseMessage saveDetailForScanCode(String vehicleSeriesId, String detailType) {
//        if (StringUtils.isBlank(vehicleSeriesId) || StringUtils.isBlank(detailType)) {
//            return Result.error("-1", "参数缺失");
//        }
//        CheckModelSeriesList checkModelSeriesList = iCheckModelSeriesListService.getById(vehicleSeriesId);
//        if (checkModelSeriesList == null) {
//            return Result.error("-2", "车型系列不存在");
//        }
//        boolean flag = checkRealVehicleVerificationService.saveCheckDetail(checkModelSeriesList, detailType);
//        if (flag) {
//            return Result.success("200", "插入成功",null);
//        } else {
//            return Result.error("-1", "插入失败");
//        }
//    }
//
//
//    /**
//     * 导入备案故障码模板
//     * @param file
//     * @Param vehicleSeriesId 车系ID
//     * @return
//     */
//    @ApiOperation(value = "|importCheckRealVVData|导入备案故障码模板")
//    @PostMapping(value = "/importCheckRealVVData")
//    public ResponseMessage importCheckRealVVData(MultipartFile file, String vehicleSeriesId) {
//        //判断上传的是否为空
//        if (file == null) {
//            return Result.success("-1", "文件为空");
//        }
//        String fileName = file.getOriginalFilename();
//        if (!fileName.endsWith("xlsx") && !fileName.endsWith("xls")){
//            return Result.error("-1", "请按照模板上传文件");
//        }
//        String result = checkRealVehicleVerificationService.importCheckRealVVData(file,vehicleSeriesId);
//        if ("导入成功".equals(result)) {
//            return Result.success("200",result, "备案故障码导入");
//        }
//        return Result.error("-1", result);
//    }
//
//    /**
//     * 生成备案故障码模板
//     * @param response
//     * @param request
//     * @param vehicleSeriesId 车系ID
//     */
//    @ApiOperation(value = "|downCheckRealVVTemplate|生成备案故障码模板")
//    @GetMapping(value = "/downCheckRealVVTemplate")
//    public void downCheckRealVVTemplate(HttpServletResponse response, HttpServletRequest request,String vehicleSeriesId){
//        OutputStream os = null;
//        Workbook workbook;
//        try {
//            response.setHeader(
//                    "Content-Disposition",
//                    "attachment; filename=" + ReadExcel.encodeFileName("备案故障码模板" + ".xlsx",request));  //这里根据下面ExcelType.XSSF配置来配，如果是 ExcelType.XSSF 对应 .xlsx ExcelType.HSSF对应.xls
//            response.setContentType("application/force-download");
//            ExportParams exportParams = new ExportParams();
//            //配置导出excel版本格式  ExcelType.XSSF后缀名为.xlsx ExcelType.HSSF后缀名为.xls
//            exportParams.setType(ExcelType.XSSF);
////            List<CheckRealVehicleVerificationDTO> list = checkRealVehicleVerificationService.selectByVehicleSeriesId(vehicleSeriesId);
//
////            if (list == null){
//                List<CheckRealVehicleVerificationDTO> list = new ArrayList<>();
////            }
////            for(int i =0; i<list.size();i++){
////                list.get(i).setId(String.valueOf(i+1));
////            }
//            iCheckOperationLogService.operationLog(request.getHeader("userId"), "生成备案故障码模板");
//            workbook = ExcelExportUtil.exportExcel(exportParams, CheckRealVehicleVerificationDTO.class, list);
//            os = response.getOutputStream();
//            workbook.write(os);
//            os.flush();
//        } catch (Exception e) {
//            throw new AdcDaBaseException("下载文件失败，请重试");
//        } finally {
//            IOUtils.closeQuietly(os);
//        }
//    }
////
////    /**
////     * 保存扫码列表
////     *
////     * @param
////     * @return
////     */
//    @ApiOperation(value = "|editScanCode|编辑扫码核查")
//    @GetMapping("/editScanCode")
//    public ResponseMessage editScanCode(String id, String value, String column, String vehicleSeriesId,String detailType) {
//        if (StringUtils.isBlank(id) || StringUtils.isBlank(column) ||  StringUtils.isBlank(vehicleSeriesId)) {
//            return Result.error("-1","参数缺失");
//        }
//        String userId = request.getHeader("userId");
//        boolean flag = checkRealVehicleVerificationService.editScanCode(id,value,column,vehicleSeriesId,userId,detailType);
//        if (flag) {
//            return Result.success("200","操作成功",null);
//        }
//        return Result.error("-1", "操作失败");
//    }
//    @ApiOperation(value = "queryRealVehicleVer|查询OBD一致性")
//    @GetMapping("/queryRealVehicleVer")
//    public ResponseMessage queryRealVehicleVer(Page page,String type,String handleType,String checkType,String vehicleSeries){
//        return Result.success("200","查询成功",checkRealVehicleVerificationService.queryRealVehicleVer(page, type, handleType, checkType, vehicleSeries));
//    }
//
//    @ApiOperation(value = "查询审核车辆")
//    @GetMapping("/queryCheckRealVehicleVer")
//    public ResponseMessage queryCheckRealVehicleVer(String vehicleSeriesId,String checkType){
//        return Result.success("200","查询成功",checkRealVehicleVerificationService.queryCheckRealVehicleVer(vehicleSeriesId,checkType));
//    }
//
    @ApiOperation(value = "修改备案故障号")
    @PutMapping("/updateCheckRealVehicleVer")
    public ResponseMessage updateCheckRealVehicleVer(@RequestBody CheckRealVehicleVerification checkRealVehicleVer){
        return Result.success("200","修改成功",checkRealVehicleVerificationService.updateCheckRealVehicleVer(checkRealVehicleVer));
    }

    @ApiOperation(value = "修改状态核查完成")
    @PutMapping("/updateCheckModelSeries")
    public ResponseMessage updateCheckModelSeries(@RequestBody CheckRealVehicleVerificationDto checkRealVehicleVerificationDto){
        return Result.success("200","修改成功",checkRealVehicleVerificationService.updateCheckModelSeries(checkRealVehicleVerificationDto));
    }

    @ApiOperation(value = "待解决核查分页查询")
    @GetMapping("/getCheckRealVehicleVerPage")
    public ResponseMessage getCheckRealVehicleVerPage(CheckRealVehicleVerification checkRealVehicleVer) throws Exception {
        return Result.success("200","待解决核查分页查询",
                checkRealVehicleVerificationService.getCheckRealVehicleVerPage(checkRealVehicleVer));
    }
//
//    /**
//     * 导出
//     * @param response
//     * @param request
//     * @return
//     */
//    @ApiOperation(value ="导出")
//    @GetMapping("/downTemplate")
//    public ResponseMessage exportObdDetail(HttpServletResponse response, HttpServletRequest request,
//                                           String id,String checkType,String handleType,String parameterName,
//                                           String project){
//        OutputStream os = null;
//        Workbook workbook = null;
//        List<String> ids = new ArrayList<>();
//        try {
//            if("1".equals(checkType)){
//                response.setHeader("Content-Disposition",
//                        "attachment; filename=" + ReadExcel.encodeFileName( "OBD核查待解决问题.xlsx", request));
//            }else if("2".equals(checkType)){
//                response.setHeader("Content-Disposition",
//                        "attachment; filename=" + ReadExcel.encodeFileName( "扫码核查待解决问题.xlsx", request));
//            }else if("3".equals(checkType)){
//                response.setHeader("Content-Disposition",
//                        "attachment; filename=" + ReadExcel.encodeFileName( "认证一致性待解决问题.xlsx", request));
//            }else if("4".equals(checkType)){
//                response.setHeader("Content-Disposition",
//                        "attachment; filename=" + ReadExcel.encodeFileName( "法规待解决问题.xlsx", request));
//            }
//            response.setContentType("application/force-download");
//            ExportParams exportParams = new ExportParams();
//            exportParams.setType(ExcelType.XSSF);
//            if(StringUtils.isNotBlank(id)){
//                ids = Arrays.asList(id.split(","));
//            }
//            if("1".equals(checkType)) {
//                List<RVVObdDTO> dates = checkRealVehicleVerificationService.getCheckRealVehicleVer(ids,checkType,
//                        handleType,parameterName);
//                if(dates.size() != 0) {
//                    for (RVVObdDTO c : dates) {
//                        if (StringUtils.isNotBlank(c.getHandleType())) {
//                            switch (c.getHandleType()) {
//                                case "0":
//                                    c.setHandleType("未处理");
//                                    break;
//                                case "1":
//                                    c.setHandleType("已处理");
//                                    break;
//                            }
//                        }
//                        if (c.getCheckPicturePathTwo() != null){
//                            c.setCheckPictureTwo(FileUtil.readFileByBytes(uploadFile+c.getCheckPicturePathTwo()));
//                        }
//                        if (c.getCheckPicturePath() != null){
//                            c.setCheckPictureOne(FileUtil.readFileByBytes(uploadFile+c.getCheckPicturePath()));
//                        }
//                    }
//                }else {
//                    dates = new ArrayList<>();
//                }
//                workbook = ExcelExportUtil.exportExcel(exportParams, RVVObdDTO.class, dates);
//            }
//            if("2".equals(checkType)) {
//                List<ScanCodeDTO> dates = checkRealVehicleVerificationService.getCheckRealVehicleVer1(ids,checkType,handleType,parameterName);
//                if(dates.size() != 0) {
//                    for (ScanCodeDTO c : dates) {
//                        if (StringUtils.isNotBlank(c.getType())) {
//                            switch (c.getType()) {
//                                case "0":
//                                    c.setType("是");
//                                    break;
//                                case "1":
//                                    c.setType("否");
//                                    break;
//                            }
//                        }
//                        if (StringUtils.isNotBlank(c.getCheckPicturePathTwo())) {
//                            switch (c.getCheckPicturePathTwo()) {
//                                case "0":
//                                    c.setCheckPicturePathTwo("是");
//                                    break;
//                                case "1":
//                                    c.setCheckPicturePathTwo("否");
//                                    break;
//                            }
//                        }
//                    }
//                }else {
//                    dates = new ArrayList<>();
//                }
//                workbook = ExcelExportUtil.exportExcel(exportParams, ScanCodeDTO.class, dates);
//            }
//            if("4".equals(checkType)) {
//                List<RegulationsDTO> dates = checkRealVehicleVerificationService.getCheckRealVehicleVer2(ids,checkType,handleType,parameterName,project);
//                if(dates.size() == 0) {
//                    dates = new ArrayList<>();
//                }
//                for (RegulationsDTO regulationsDTO : dates) {
//                    if (regulationsDTO.getCheckPicturePathTwo() != null){
//                        regulationsDTO.setCheckPictureTwo(FileUtil.readFileByBytes(uploadFile+regulationsDTO.getCheckPicturePathTwo()));
//                    }
//                    if (regulationsDTO.getCheckPicturePath() != null){
//                        regulationsDTO.setCheckPictureOne(FileUtil.readFileByBytes(uploadFile+regulationsDTO.getCheckPicturePath()));
//                    }
//                }
//                workbook = ExcelExportUtil.exportExcel(exportParams, RegulationsDTO.class, dates);
//            }
//            if("3".equals(checkType)) {
//                List<CertificationDTO> dates = checkRealVehicleVerificationService.getCheckRealVehicleVer3(ids,checkType,handleType,parameterName);
////                if(dates.size() != 0) {
////                    dates = new ArrayList<>();
////                }
//                for (CertificationDTO regulationsDTO : dates) {
//                    if (regulationsDTO.getCheckPicturePathTwo() != null){
//                        regulationsDTO.setCheckPictureTwo(FileUtil.readFileByBytes(uploadFile+regulationsDTO.getCheckPicturePathTwo()));
//                    }
//                    if (regulationsDTO.getCheckPicturePath() != null){
//                        regulationsDTO.setCheckPictureOne(FileUtil.readFileByBytes(uploadFile+regulationsDTO.getCheckPicturePath()));
//                    }
//                }
//                workbook = ExcelExportUtil.exportExcel(exportParams, CertificationDTO.class, dates);
//            }
//            os = response.getOutputStream();
//            workbook.write(os);
//            os.flush();
//        } catch (Exception e) {
//            e.printStackTrace();
//            throw new AdcDaBaseException("下载文件失败，请重试");
//        } finally {
//            IOUtils.closeQuietly(os);
//        }
//        return Result.success("0", "操作成功");
//    }
//    /**
//     * 查询上次改动不一致性的数据
//     * @param
//     * @return
//     */
//    @GetMapping("/getLastCheckRealVehicleVer")
//    public ResponseMessage getLastCheckRealVehicleVer(CheckModelSeriesList checkModelSeriesList){
//        return Result.success("200","查询成功",checkRealVehicleVerificationService.getLastCheckRealVehicleVer(checkModelSeriesList));
//
//    }
}
