package com.adc.da.system.controller;


import com.adc.da.system.entity.VehicleDatabase;
import com.adc.da.system.entity.VehicleDatabaseDetails;
import com.adc.da.system.service.IVehicleDatabaseDetailsService;
import com.adc.da.system.service.IVehicleDatabaseService;

import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;

/**
 * 车型库控制器
 */
@RestController
@Api(value = "车型库控制器")
@RequestMapping("/${restPath}/vehicleDatabase")
public class VehicleDatabaseController {
    /**
     * request
     */
    @Autowired
    private HttpServletRequest request;
    /**
     * 日志service
     */
//    @Autowired
//    private ICheckOperationLogService iCheckOperationLogService;
    /**
     * vehicleDatabaseService
     */
    @Autowired
    private IVehicleDatabaseService vehicleDatabaseService;

    /**
     * vehicleDatabaseDetailsService
     */
    @Autowired
    private IVehicleDatabaseDetailsService vehicleDatabaseDetailsService;

    /**
     * cerValidityService
     */
//    @Autowired
//    private ICerValidityService cerValidityService;

    /**
     * 车型库分页
     */
    @ApiOperation(value = "|queryByPage|车型库分页")
    @GetMapping("/queryByPage")
    public ResponseMessage queryByPage(VehicleDatabase vehicleDatabase) {
        if (StringUtils.isNotEmpty(vehicleDatabase.getModelCode())) {
            vehicleDatabase.setModelCode(vehicleDatabase.getModelCode().toUpperCase());
        }
        Page page = new Page(vehicleDatabase.getPage(),vehicleDatabase.getPageSize());
        return Result.success("200", "车型库分页", vehicleDatabaseService.queryByPage(page, vehicleDatabase));
    }

    /**
     * 车型库详情分页
     */
    @ApiOperation(value = "|queryDetailsByPage|车型库详情分页")
    @GetMapping("/queryDetailsByPage")
    public ResponseMessage queryDetailsByPage(VehicleDatabaseDetails vehicleDatabaseDetails) {
        Page page = new Page(vehicleDatabaseDetails.getPage(),vehicleDatabaseDetails.getPageSize());
        return Result.success("200", "车型库详情分页", vehicleDatabaseDetailsService.queryDetailsByPage(page,vehicleDatabaseDetails));
    }

    /**
     * 零部件待解决问题
     * @param vehicleDatabaseDetails
     * @return
     */
    @ApiOperation(value = "|queryDetailsByPage|零部件待解决问题分页")
    @GetMapping("/queryVehicleDatabaseDetails")
    public ResponseMessage queryVehicleDatabaseDetailsPage(VehicleDatabaseDetails vehicleDatabaseDetails) {
        Page page = new Page(vehicleDatabaseDetails.getPage(),vehicleDatabaseDetails.getPageSize());
        return Result.success("200", "零部件待解决问题分页", vehicleDatabaseService.queryVehicleDatabaseDetailsPage(page,vehicleDatabaseDetails));
    }

    /**
     * 添加车型库信息
     *
     * @param vehicleDatabase
     * @return
     */
//    @ApiOperation(value = "|saveInfo|添加证书有效性核查")
//    @PostMapping("/saveInfo")
//    public ResponseMessage saveInfo(@RequestBody VehicleDatabase vehicleDatabase) {
//        QueryWrapper queryWrapper = new QueryWrapper();
//        queryWrapper.eq("ID",vehicleDatabase.getId());
//        queryWrapper.eq("MODEL_CODE",vehicleDatabase.getModelCode());
//        queryWrapper.eq("BASE",vehicleDatabase.getBase());
//        if (vehicleDatabaseService.getOne(queryWrapper) != null){
//            return Result.error("-1","CCC系统编号和车型名称重复");
//        }
//        SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss ");
//        vehicleDatabase.setCreateTime(simpleDateFormat.format(new Date()));
//        vehicleDatabase.setAuditStatus("导入");
//        if (vehicleDatabaseService.save(vehicleDatabase)){
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "新增车型库信息");
//            return Result.success("200","操作成功",null);
//        }
//        return Result.error("-1","操作失败");
//    }
    /**
     * 添加车型库详情信息
     *
     * @param vehicleDatabaseDetails
     * @return
     */
//    @ApiOperation(value = "|saveDetailsInfo|添加车型库详情信息")
//    @PostMapping("/saveDetailsInfo")
//    public ResponseMessage saveDetailsInfo(@RequestBody VehicleDatabaseDetails vehicleDatabaseDetails) {
//        QueryWrapper queryWrapper = new QueryWrapper();
//        if (vehicleDatabaseDetails.getPartName() != null){
//            queryWrapper.eq("PART_NAME",vehicleDatabaseDetails.getPartName());
//            queryWrapper.eq("CCC_ID",vehicleDatabaseDetails.getCccId());
//            queryWrapper.eq("MODEL_CODE",vehicleDatabaseDetails.getModelCode());
//            queryWrapper.eq("BASE",vehicleDatabaseDetails.getBase());
//            if (vehicleDatabaseDetailsService.getOne(queryWrapper) != null){
//                return Result.error("-1","零部件名称重复");
//            }
//        }
//        if (vehicleDatabaseDetails.getCccNumCer() != null){
//            QueryWrapper queryWrapper1 = new QueryWrapper();
//            queryWrapper1.eq("CCC_NUM_CER",vehicleDatabaseDetails.getCccNumCer());
//            queryWrapper1.eq("CCC_ID",vehicleDatabaseDetails.getCccId());
//            queryWrapper1.eq("MODEL_CODE",vehicleDatabaseDetails.getModelCode());
//            queryWrapper1.eq("BASE",vehicleDatabaseDetails.getBase());
//            if (vehicleDatabaseDetailsService.getOne(queryWrapper1) != null){
//                return Result.error("-1","CCC证书编号重复");
//            }
//        }
//        vehicleDatabaseDetails.setId(UUIDUtils.getUUID());
//        vehicleDatabaseDetails.setType(1);
//        if (vehicleDatabaseDetailsService.save(vehicleDatabaseDetails)){
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "新增车型库详情信息");
//            return Result.success("200","操作成功",null);
//        }
//        return Result.error("-1","操作失败");
//    }

    /**
     * 删除车型库信息
     *
     * @param id
     * @return
     */
//    @ApiOperation(value = "|deleteById|删除车型库信息")
//    @DeleteMapping(value = "/deleteById")
//    public ResponseMessage deleteById(String id,String modelCode, String base, String auditStatus) {
//        QueryWrapper queryWrapper = new QueryWrapper();
//        queryWrapper.eq("ID",id);
//        queryWrapper.eq("MODEL_CODE",modelCode);
//        queryWrapper.eq("BASE",base);
//        QueryWrapper queryWrapper1 = new QueryWrapper();
//        queryWrapper1.eq("CCC_ID",id);
//        queryWrapper1.eq("MODEL_CODE",modelCode);
//        queryWrapper1.eq("BASE",base);
//        queryWrapper1.eq("AUDIT_STATUS",auditStatus);
//        if (cerValidityService.getOne(queryWrapper1) != null){
//            return Result.error("-1", "添加到证书有效性核查的数据不可删除",false);
//        }
//        if (vehicleDatabaseService.remove(queryWrapper)) {
//            QueryWrapper queryWrapper2 = new QueryWrapper();
//            queryWrapper2.eq("CCC_ID",id);
//            queryWrapper2.eq("MODEL_CODE",modelCode);
//            queryWrapper2.eq("BASE",base);
//            vehicleDatabaseDetailsService.remove(queryWrapper2);
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "删除车型库信息");
//            return Result.success("200", "操作成功",true);
//        }
//        return Result.error("-1", "操作失败",false);
//    }
    /**
     * 删除车型库详情信息
     *
     * @param id
     * @return
     */
//    @ApiOperation(value = "|deleteDetailsById|删除车型库详情信息")
//    @DeleteMapping(value = "/deleteDetailsById")
//    public ResponseMessage deleteDetailsById(String id) {
//        List<String> idList = Arrays.asList(id.split(","));
//        if (vehicleDatabaseDetailsService.removeByIds(idList)) {
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "删除车型库详情信息");
//            return Result.success("200", "操作成功",true);
//        }
//        return Result.error("-1", "操作失败",false);
//    }

    /**
     * 生成详情模板
     *
     * @param response
     */
//    @ApiOperation(value = "|downTemplate|生成详情模板")
//    @GetMapping(value = "/downTemplate")
//    public void downTemplate(HttpServletResponse response, HttpServletRequest request) {
//        OutputStream os = null;
//        Workbook workbook = null;
//        try {
//            response.setHeader(
//                    "Content-Disposition",
//                    "attachment; filename=" + ReadExcel.encodeFileName("车型库详情模板" + ".xlsx", request));
//            response.setContentType("application/force-download");
//            ExportParams exportParams = new ExportParams();
//            exportParams.setType(ExcelType.XSSF);
//            List<VehicleDatabaseDetailsDto> list = new ArrayList<>();
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "导出车型库详情信息模板");
//            workbook = ExcelExportUtil.exportExcel(exportParams, VehicleDatabaseDetailsDto.class, list);
//            os = response.getOutputStream();
//            workbook.write(os);
//            os.flush();
//        } catch (Exception e) {
//            throw new AdcDaBaseException("下载文件失败，请重试");
//        } finally {
//            IOUtils.closeQuietly(os);
//        }
//    }


    /**
     * 导入详情
     *
     * @param file
     * @return
     * @throws IOException
     */
//    @ApiOperation(value = "|importDetails|导入详情")
//    @PostMapping(value = "/importDetails")
//    public ResponseMessage importDetails(MultipartFile file, String cccId, String modelCode, String base) {
//        if (file == null) {
//            return Result.success("-1", "文件为空");
//        }
//        Map<String,Object> map = vehicleDatabaseDetailsService.importDetails(file, cccId, modelCode,base);
//        if (map != null && map.get("error") == null){
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "导入车型库详情信息");
//            return Result.success("200", "操作成功", map);
//        }else if ( map != null && map.get("error") != null && map.get("error").equals(1)){
//            return Result.error("-1", "所有字段长度在1~30字符");
//        }
//        return Result.error("-1","请按照模板上传文件");
//    }

    /**
     * 导出零部件待解决问题
     *
     * @param response
     */
//    @ApiOperation(value = "|downTemplate|")
//    @GetMapping(value = "/downDetails")
//    public void downDetails(HttpServletResponse response, HttpServletRequest request,VehicleDatabaseDetails vehicleDatabaseDetails) {
//        OutputStream os = null;
//        Workbook workbook = null;
//        try {
//            response.setHeader(
//                    "Content-Disposition",
//                    "attachment; filename=" + ReadExcel.encodeFileName("零部件待解决问题" + ".xlsx", request));
//            response.setContentType("application/force-download");
//            ExportParams exportParams = new ExportParams();
//            exportParams.setType(ExcelType.XSSF);
//            List<VehicleDatabaseDetaDTO> list = vehicleDatabaseService.queryVehicleDatabaseDetails(vehicleDatabaseDetails);
//            for (VehicleDatabaseDetaDTO v:list) {
//                if("1".equals(v.getType())){
//                    v.setType("未处理");
//                }else {
//                    v.setType("已处理");
//                }
//            }
//            iCheckOperationLogService.operationLog(
//                    request.getHeader("userId"),
//                    "导出零部件待解决问题");
//            workbook = ExcelExportUtil.exportExcel(exportParams, VehicleDatabaseDetaDTO.class, list);
//            os = response.getOutputStream();
//            workbook.write(os);
//            os.flush();
//        } catch (Exception e) {
//            throw new AdcDaBaseException("下载文件失败，请重试");
//        } finally {
//            IOUtils.closeQuietly(os);
//        }
//    }

    /**
     * 零部件不一致处理
     * @param id  id
     * @return
     */
    @ApiOperation(value = "零部件不一致处理")
    @PutMapping(value = "/updateType")
    public ResponseMessage updateType(@RequestBody VehicleDatabaseDetails vehicleDatabaseDetails){
        UpdateWrapper updateWrapper = new UpdateWrapper();
        updateWrapper.eq("CCC_NUM_CER",vehicleDatabaseDetails.getCccNumCer());
        updateWrapper.set("TYPE",2);
        vehicleDatabaseDetailsService.update(updateWrapper);
        return Result.success("200", "操作成功",true);
    }
}
